@@ -30,7 +30,7 @@ use constant  AWS_CONTAINER_CREDENTIALS_URL          => 'http://169.254.170.2';
 
 use vars qw/$VERSION @EXPORT/;
 
-$VERSION = '1.0.13'; $VERSION=~s/\-.*$//;
+$VERSION = '1.0.14'; $VERSION=~s/\-.*$//;
 
 @EXPORT = qw/$VERSION/;
 
@@ -211,7 +211,7 @@ sub new {
   my $class = shift;
   my $self = $class->SUPER::new(ref($_[0]) ? $_[0] : { @_ });
 
-  if ( !$self->get_logger ) {
+  if ( !$self->get_logger || reftype($self->get_logger) ne 'CODE' ) {
     $self->set_logger(bless { debug => $self->get_debug }, 'Amazon::Credentials::Logger');
     $self->get_logger->debug("WARNING: DEBUG mode using default logger");
   }
